# package_name

Description. 
The package gerlida_cpf is used to:
	- Generate a random CPF number
	- Check if a CPF number is valid

## Installation

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install package_name

```bash
pip install gerlida_cpf
```

## Usage

```python
from gerlida_cpf.gera_cpf import gerador_cpf
gerador_cpf.geracpf()
```

```python
from gerlida_cpf.valida_cpf import validacpf
valida_cpf.validacpf()
```

## Author
My_name

## License
[MIT](https://choosealicense.com/licenses/mit/)